@@ -1,6 +1,6 @@
 `compHclust.heatmap` <-
 function(x,xhc,gi,d.title="Cluster Dendrogram",hm.lab=TRUE,hm.lab.cex=1,
-                               d.ht=0.25,gi.width=0.5,d.mar=c(0,4,4,2),hm.mar=c(5,4,2,2)) {
+         d.ht=0.25,gi.width=0.5,d.mar=c(0,4,4,2),hm.mar=c(5,4,2,2)) {
   if (class(xhc)!="hclust") {
     stop("'xhc' must be of class 'hclust'")
   }
@@ -14,7 +14,8 @@ function(x,xhc,gi,d.title="Cluster Dendrogram",hm.lab=TRUE,hm.lab.cex=1,
   par(mar=d.mar)
   plot(as.dendrogram(xhc),axes=FALSE,xaxs="i",leaflab="none",main=d.title)
   par(mar=hm.mar)
-  image(1:ncol(x),1:nrow(x),t(x[,xhc$order])[,nrow(x):1],axes=FALSE,xlab="",ylab="")
+  image(1:ncol(x),1:nrow(x),t(x[,xhc$order])[,nrow(x):1],axes=FALSE,xlab="",
+        ylab="")
   if (hm.lab) {
     axis(3,1:ncol(x),labels=xhc$order,tick=0,cex.axis=hm.lab.cex)
   }
